@@ -14,10 +14,12 @@ from enum import IntEnum
 from enum import unique
 from functools import total_ordering
 
+from gi.repository import GdkPixbuf
 from gi.repository import Gio
 from nbxmpp.const import PresenceShow
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
+from PIL import Image
 
 from gajim.common.i18n import _
 from gajim.common.i18n import p_
@@ -25,7 +27,7 @@ from gajim.common.i18n import p_
 STOP_EVENT = True
 PROPAGATE_EVENT = False
 
-MAX_MESSAGE_CORRECTION_DELAY = 300
+MAX_MESSAGE_CORRECTION_DELAY = 3600
 
 
 class EncryptionInfoMsg(Enum):
@@ -38,6 +40,7 @@ class EncryptionInfoMsg(Enum):
                       'Querying for devices now…')
     UNDECIDED_FINGERPRINTS = _('There are devices for which you have not made '
                                'a trust decision yet.')
+    SESSION_BUILD = _('Successfully build new session with {device_id}.')
 
 
 class Entity(NamedTuple):
@@ -59,9 +62,9 @@ class AvatarSize(IntEnum):
     ROSTER = 32
     START_CHAT = 32
     VCARD_HEADER = 40
-    ACCOUNT_SIDE_BAR = 40
+    ACCOUNT_SIDE_BAR = 24
     ACCOUNT_SIDE_BAR_WARNING = 20
-    WORKSPACE = 40
+    WORKSPACE = 36
     WORKSPACE_EDIT = 100
     CHAT = 48
     MESSAGE_REPLY = 24
@@ -69,7 +72,7 @@ class AvatarSize(IntEnum):
     CALL = 100
     CALL_BIG = 200
     GROUP_INFO = 100
-    TOOLTIP = 100
+    TOOLTIP = 72
     ACCOUNT_PAGE = 150
     ACTIVITY_PAGE = 100
     VCARD = 200
@@ -105,7 +108,7 @@ class StyleAttr(Enum):
 
 @unique
 class CSSPriority(IntEnum):
-    PRE_APPLICATION = 599
+    PRE_THEME = 199
     APPLICATION = 600
     APPLICATION_DARK = 601
     DEFAULT_THEME = 610
@@ -918,7 +921,7 @@ NONREGISTERED_URI_SCHEMES = {
 # This is an excerpt of Media Types from
 # https://www.iana.org/assignments/media-types/media-types.xhtml
 # plus some additions
-MIME_TYPES = (
+OTHER_MIME_TYPES = {
     # application/
     'application/calendar+json',
     'application/calendar+xml',
@@ -926,7 +929,6 @@ MIME_TYPES = (
     'application/json',
     'application/mp4',
     'application/msword',
-    'application/octet-stream',
     'application/ogg',
     'application/pdf',
     'application/pgp-encrypted',
@@ -963,7 +965,23 @@ MIME_TYPES = (
     # End office
     'application/vnd.sqlite3',
     'application/zip',
-    # audio/*
+    # font/*
+    'font/ttf',
+    'font/woff',
+    'font/woff2',
+    # model/*
+    'model/mtl',
+    'model/obj',
+    'model/stl',
+    # text/*
+    'text/calendar',
+    'text/csv',
+    'text/markdown',
+    'text/rtf',
+    'text/vcard',
+}
+
+AUDIO_MIME_TYPES = {
     'audio/aac',
     'audio/ac3',
     'audio/flac',
@@ -983,41 +1001,9 @@ MIME_TYPES = (
     'audio/x-mpeg',
     'audio/x-ogg',
     'audio/x-wav',
-    # font/*
-    'font/ttf',
-    'font/woff',
-    'font/woff2',
-    # image/*
-    'image/webp',
-    'image/avif',
-    'image/jxl',
-    'image/bmp',
-    'image/x-bmp',
-    'image/x-ms-bmp',
-    'image/gif',
-    'image/heic',
-    'image/heif',
-    'image/jpeg',
-    'image/png',
-    'image/svg+xml',
-    'image/tiff',
-    'image/vnd.adobe.photoshop',
-    'image/vnd.dwg',
-    'image/vnd.dxf',
-    'image/vnd.microsoft.icon',
-    'image/x-icon',
-    'image/x-xcf',
-    # model/*
-    'model/mtl',
-    'model/obj',
-    'model/stl',
-    # text/*
-    'text/calendar',
-    'text/csv',
-    'text/markdown',
-    'text/rtf',
-    'text/vcard',
-    # video/*
+}
+
+VIDEO_MIME_TYPES = {
     'video/H264',
     'video/H265',
     'video/mp4',
@@ -1029,20 +1015,57 @@ MIME_TYPES = (
     'video/webm',
     'video/x-matroska',
     'video/x-msvideo',
+}
+
+
+def get_pixbuf_mime_types() -> set[str]:
+    pixbuf_mime_types: set[str] = set()
+
+    for fmt in GdkPixbuf.Pixbuf.get_formats():
+        mime_types = fmt.get_mime_types()
+        if mime_types is None:
+            continue
+        for mime_type in mime_types:
+            pixbuf_mime_types.add(mime_type.lower())
+
+    return pixbuf_mime_types
+
+
+def get_pil_mime_types() -> set[str]:
+    pil_mime_types: set[str] = set()
+
+    Image.init()
+    for mime_type in Image.MIME.values():
+        pil_mime_types.add(mime_type.lower())
+
+    return set(filter(
+        lambda mime_type: mime_type.startswith('image'),
+        pil_mime_types
+    ))
+
+
+PIL_IMAGE_MIME_TYPES = get_pil_mime_types()
+PIXBUF_IMAGE_MIME_TYPES = get_pixbuf_mime_types()
+IMAGE_MIME_TYPES = PIL_IMAGE_MIME_TYPES | PIXBUF_IMAGE_MIME_TYPES
+
+ALL_MIME_TYPES = (
+    OTHER_MIME_TYPES |
+    IMAGE_MIME_TYPES |
+    AUDIO_MIME_TYPES |
+    VIDEO_MIME_TYPES
 )
 
-
 TRUST_SYMBOL_DATA = {
-    Trust.UNTRUSTED: ('dialog-error-symbolic',
+    Trust.UNTRUSTED: ('lucide-circle-x-symbolic',
                       _('Untrusted'),
                       'error-color'),
-    Trust.UNDECIDED: ('security-low-symbolic',
+    Trust.UNDECIDED: ('lucide-shield-alert-symbolic',
                       _('Trust Not Decided'),
                       'warning-color'),
-    Trust.BLIND: ('security-medium-symbolic',
+    Trust.BLIND: ('lucide-shield-question-mark-symbolic',
                   _('Blind Trust'),
                   'encrypted-color'),
-    Trust.VERIFIED: ('security-high-symbolic',
+    Trust.VERIFIED: ('lucide-shield-check-symbolic',
                      _('Verified'),
                      'encrypted-color')
 }
